//@line 36 "/builds/slave/tb-rel-c-beta-l64_rpk_5-000000/l10n/id/calendar/lightning-l10n.js"

//@line 38 "/builds/slave/tb-rel-c-beta-l64_rpk_5-000000/l10n/id/calendar/lightning-l10n.js"

//@line 41 "/builds/slave/tb-rel-c-beta-l64_rpk_5-000000/l10n/id/calendar/lightning-l10n.js"
pref("calendar.week.start", 0);

//@line 44 "/builds/slave/tb-rel-c-beta-l64_rpk_5-000000/l10n/id/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "id");

//@line 55 "/builds/slave/tb-rel-c-beta-l64_rpk_5-000000/l10n/id/calendar/lightning-l10n.js"
pref("calendar.categories.names", "Perayaan,Ultah,Bisnis,Telepon,Klien,Kompetitor,Pelanggan,Favorit,Tindak Lanjut,Hadiah,Liburan,Ide,Masalah,Pertemuan,Lain-lain,Personal,Projek,Hari Libur Nasional,Status,Supplier,Travel,Cuti");
